# Hie-RAG

Hie-RAG is a Hierarchical Retrieval-Augmented Generation framework for question answering.

# Introduction

It is designed to improve the retrieval quality and generation quality of the RAG model by introducing a hierarchical structure. The framework consists of two main parts: a higher-level summary retriever and a lower-level document retriever.

# Installation

```bash
pip install hie-rag
```
